@@ -1,4 +1,3 @@
 from globus_cli.commands.endpoint.permission.commands import permission_command
 
-
-__all__ = ['permission_command']
+__all__ = ["permission_command"]
